@@ -2,13 +2,13 @@
 **
 ** mycopy4_clp.h
 **
-** Sun Mar 14 16:38:29 2010
-** Linux 2.6.23 (#9 Sun Jan 27 22:29:05 CET 2008) i686
+** Thu Mar 22 20:21:06 2012
+** Linux 2.6.36 (#6 Sun Jun 5 09:23:00 CEST 2011) i686
 ** linux@mgpc (Michael Geng)
 **
 ** Header file for command line parser class
 **
-** Automatically created by genparse v0.8.7
+** Automatically created by genparse v0.9.0
 **
 ** See http://genparse.sourceforge.net for details and updates
 **
@@ -57,10 +57,10 @@ public:
   bool my_callback ();
   bool outfile_cb ();
 
-  int i () { return _i; }
-  std::string o () { return _o; }
-  bool h () { return _h; }
-  bool v () { return _v; }
+  int i () const { return _i; }
+  std::string o () const { return _o; }
+  bool h () const { return _h; }
+  bool v () const { return _v; }
 };
 
 #endif
