@@ -1,7 +1,7 @@
 /** @file cpp_clparam_list.cc
 \brief Methods for the C++ implementation of the command line parser */
 /*
- * Copyright (C) 2000, 2006, 2007, 2008
+ * Copyright (C) 2000, 2006 - 2012
  * Michael S. Borella <mike@borella.net> and
  * Michael Geng       <linux@MichaelGeng.de>
  *
@@ -169,13 +169,13 @@ void CPP_Clparam_list::output_interface (const string filename_without_extension
   for (iter = params.begin (); iter != params.end (); iter++)
     {
       o << "  " << type2str (iter->get_type ()) << ' ' << get_parameter_name (*iter)
-        << " () { return _" << get_parameter_name (*iter) << "; }" << endl;
+        << " () const { return _" << get_parameter_name (*iter) << "; }" << endl;
       if (iter->requires_additional_flag_arg ())
         o << "  " << type2str (flag_type) << ' ' << get_parameter_name (*iter) << "_flag"
-          << " () { return _" << get_parameter_name (*iter) << "_flag; }" << endl;
+          << " () const { return _" << get_parameter_name (*iter) << "_flag; }" << endl;
       if (iter->get_store_longindex ())
         o << "  " << type2str (int_type) << ' ' << get_parameter_name (*iter) << "_li"
-          << " () { return _" << get_parameter_name (*iter) << "_li; }" << endl;
+          << " () const { return _" << get_parameter_name (*iter) << "_li; }" << endl;
     }
 
   // closing bracket for class definition
