@@ -1,22 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program. If not, see <http://www.gnu.org/licenses/>.*/
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -27,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -45,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -53,11 +54,75 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 22 "parser.yy"
+
+
+#include <iostream>
+#include <cstdio>
+#include <string>
+#include <cstring>
+#include "genparse.h"
+#include "clparam_list.h"
+#include "logfile.h"
+#include "unique_int.h"
+
+#define YYDEBUG 1
+
+// These  prototypes are necessary for C++ compilation
+int yyerror (char *);
+int yylex ();
+void dump_short_reps (char *);
+void add_param_to_list ();
+void dump_param_type (param_type);
+
+// These are all defined in genparse.cc
+extern Clparam_list *my_params;
+extern Unique_Int longopt_value;
+extern Logfile mylog;
+extern int yylineno;
+extern char *yyfilename;
+
+// This is an object we use over and over to read in parameters
+Clparam *param;
+
+
+
+/* Line 189 of yacc.c  */
+#line 106 "parser.cc"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -177,81 +242,33 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 24 "parser.yy"
-
-
-#include <iostream>
-#include <cstdio>
-#include <string>
-#include <cstring>
-#include "genparse.h"
-#include "clparam_list.h"
-#include "logfile.h"
-#include "unique_int.h"
-
-#define YYDEBUG 1
-
-// These  prototypes are necessary for C++ compilation
-int yyerror (char *);
-int yylex ();
-void dump_short_reps (char *);
-void add_param_to_list ();
-void dump_param_type (param_type);
-
-// These are all defined in genparse.cc
-extern Clparam_list *my_params;
-extern Unique_Int longopt_value;
-extern Logfile mylog;
-extern int yylineno;
-extern char *yyfilename;
-
-// This is an object we use over and over to read in parameters
-Clparam *param;
-
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 59 "parser.yy"
 {
+
+/* Line 214 of yacc.c  */
+#line 57 "parser.yy"
+
   char    *str;  /* string */
   int     i;
   param_type p;
-}
-/* Line 187 of yacc.c.  */
-#line 244 "parser.cc"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 260 "parser.cc"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 257 "parser.cc"
+/* Line 264 of yacc.c  */
+#line 272 "parser.cc"
 
 #ifdef short
 # undef short
@@ -326,14 +343,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -414,9 +431,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -450,12 +467,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -573,17 +590,17 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    83,    83,    84,    87,    88,    89,    92,    93,    94,
-      95,    96,    97,    98,   101,   107,   115,   123,   129,   137,
-     145,   152,   159,   166,   167,   171,   171,   178,   181,   188,
-     189,   190,   193,   199,   200,   205,   206,   211,   212,   217,
-     222,   223,   226,   227,   230,   233,   240,   247,   257,   268,
-     275,   282,   289,   294,   302,   303,   307,   313,   314,   315,
-     318,   323,   330,   336,   337,   341,   347,   353,   361,   362,
-     370,   378,   386,   394,   395,   403,   404,   405,   408,   409,
-     410,   413,   416,   422,   426,   432,   438,   441,   442,   445,
-     448,   454,   462,   463,   464,   467,   475,   476,   479,   485,
-     492,   495,   499,   503
+       0,    81,    81,    82,    85,    86,    87,    90,    91,    92,
+      93,    94,    95,    96,    99,   105,   113,   121,   127,   135,
+     143,   150,   157,   164,   165,   169,   169,   176,   179,   186,
+     187,   188,   191,   197,   198,   203,   204,   209,   210,   215,
+     220,   221,   224,   225,   228,   231,   238,   245,   255,   266,
+     273,   280,   287,   292,   300,   301,   305,   311,   312,   313,
+     316,   321,   328,   334,   335,   339,   345,   351,   359,   360,
+     368,   376,   384,   392,   393,   401,   402,   403,   406,   407,
+     408,   411,   414,   420,   424,   430,   436,   439,   440,   443,
+     446,   452,   460,   461,   462,   465,   473,   474,   477,   483,
+     490,   493,   497,   501
 };
 #endif
 
@@ -605,7 +622,7 @@ static const char *const yytname[] =
   "INTMAX", "UINTMAX", "FLOAT", "DOUBLE", "CHAR", "STRING", "$accept",
   "all", "globals", "global", "include", "mandatory", "exit_value",
   "break_lines", "export_long_options", "no_struct", "global_callback",
-  "entries", "entry", "@1", "new_entry", "options", "option", "descs",
+  "entries", "entry", "$@1", "new_entry", "options", "option", "descs",
   "err_msg", "err_msg_arg", "comment", "gp_include", "param",
   "short_params", "long_param", "mandatory_opt_name", "optional_opt_name",
   "multi_long_option", "long_option", "type", "default", "range",
@@ -963,17 +980,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1007,11 +1027,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1291,10 +1311,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1310,11 +1328,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1322,9 +1339,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1348,14 +1365,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1363,51 +1405,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1437,7 +1456,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1445,7 +1463,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1468,9 +1485,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1481,7 +1497,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1491,6 +1506,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1499,16 +1517,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1540,20 +1558,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1593,7 +1607,9 @@ yyreduce:
   switch (yyn)
     {
         case 14:
-#line 102 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 100 "parser.yy"
     {
 		my_params->add_include ((string)"<" + (yyvsp[(3) - (4)].str) + ">");
 		mylog.write ((string) "adding include file: <" + (yyvsp[(3) - (4)].str) + ">");
@@ -1602,7 +1618,9 @@ yyreduce:
     break;
 
   case 15:
-#line 108 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 106 "parser.yy"
     {
 		my_params->add_include ((string)"\"" + (yyvsp[(3) - (4)].str) + "\"");
 		mylog.write ((string) "adding include file: \"" + (yyvsp[(3) - (4)].str) + "\"");
@@ -1611,7 +1629,9 @@ yyreduce:
     break;
 
   case 16:
-#line 116 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 114 "parser.yy"
     {
 		my_params->add_mandatory ((yyvsp[(2) - (2)].str));
 		mylog.write ((string) "adding mandatory: " + (yyvsp[(2) - (2)].str));
@@ -1620,7 +1640,9 @@ yyreduce:
     break;
 
   case 17:
-#line 124 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 122 "parser.yy"
     {
 		my_params->set_exit_value ((yyvsp[(2) - (2)].str));
 		mylog.write ((string) "adding exit value: " + (yyvsp[(2) - (2)].str));
@@ -1629,7 +1651,9 @@ yyreduce:
     break;
 
   case 18:
-#line 130 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 128 "parser.yy"
     {
 		my_params->set_exit_value ((yyvsp[(2) - (2)].str));
 		mylog.write ((string) "adding exit value: " + (yyvsp[(2) - (2)].str));
@@ -1638,7 +1662,9 @@ yyreduce:
     break;
 
   case 19:
-#line 138 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 136 "parser.yy"
     {
 		my_params->set_break_lines ((yyvsp[(2) - (2)].str));
 		mylog.write ((string) "breaking lines to a width of: " + (yyvsp[(2) - (2)].str));
@@ -1647,7 +1673,9 @@ yyreduce:
     break;
 
   case 20:
-#line 146 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 144 "parser.yy"
     {
 		my_params->set_export_long_options (true);
 		mylog.write ((string) "exporting long options struct");
@@ -1655,7 +1683,9 @@ yyreduce:
     break;
 
   case 21:
-#line 153 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 151 "parser.yy"
     {
 		my_params->set_no_struct (true);
 		mylog.write ((string) "do not auto generate a struct / class for parsing results");
@@ -1663,7 +1693,9 @@ yyreduce:
     break;
 
   case 22:
-#line 160 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 158 "parser.yy"
     {
 		my_params->set_global_callback ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "setting global callback: " + (yyvsp[(1) - (1)].str));
@@ -1671,21 +1703,27 @@ yyreduce:
     break;
 
   case 25:
-#line 171 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 169 "parser.yy"
     {
 		param = new Clparam; mylog.write ("reading parameter...");
 	}
     break;
 
   case 26:
-#line 175 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 173 "parser.yy"
     {
 		add_param_to_list ();
 	}
     break;
 
   case 28:
-#line 182 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 180 "parser.yy"
     {
 		param->set_type ((yyvsp[(2) - (3)].p));
 		dump_param_type ((yyvsp[(2) - (3)].p));
@@ -1693,7 +1731,9 @@ yyreduce:
     break;
 
   case 32:
-#line 194 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 192 "parser.yy"
     {
 		param->set_default_value ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "  default value: " + (yyvsp[(1) - (1)].str));
@@ -1702,7 +1742,9 @@ yyreduce:
     break;
 
   case 34:
-#line 201 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 199 "parser.yy"
     {
 		param->set_callback ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "  callback: " + (yyvsp[(1) - (1)].str));
@@ -1710,7 +1752,9 @@ yyreduce:
     break;
 
   case 36:
-#line 207 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 205 "parser.yy"
     {
 		param->set_store_longindex (true);
 		mylog.write ((string) "  longindex for this parameter must be stored");
@@ -1718,7 +1762,9 @@ yyreduce:
     break;
 
   case 38:
-#line 213 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 211 "parser.yy"
     {
 		param->set_add_flag (true);
 		mylog.write ((string) "  this parameter also gets a flag");
@@ -1726,7 +1772,9 @@ yyreduce:
     break;
 
   case 39:
-#line 218 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 216 "parser.yy"
     {
 		param->set_do_not_document (true);
 		mylog.write ((string) "  do not document this parameter");
@@ -1734,7 +1782,9 @@ yyreduce:
     break;
 
   case 45:
-#line 234 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 232 "parser.yy"
     {
 		param->set_err_msg ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "  conversion error message: " + (yyvsp[(1) - (1)].str));
@@ -1743,7 +1793,9 @@ yyreduce:
     break;
 
   case 46:
-#line 241 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 239 "parser.yy"
     {
 		param->set_err_msg (string("\"") + (yyvsp[(1) - (1)].str) + '\"');
 		mylog.write ((string) "  conversion error message: \"" + (yyvsp[(1) - (1)].str) + '\"');
@@ -1752,7 +1804,9 @@ yyreduce:
     break;
 
   case 47:
-#line 248 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 246 "parser.yy"
     {
 		param->set_err_msg ((yyvsp[(1) - (3)].str));
 		mylog.write ((string) "  conversion error message: " + (yyvsp[(1) - (3)].str));
@@ -1764,7 +1818,9 @@ yyreduce:
     break;
 
   case 48:
-#line 258 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 256 "parser.yy"
     {
 		param->set_err_msg (string("\"") + (yyvsp[(1) - (3)].str) + '\"');
 		mylog.write ((string) "  conversion error message: \"" + (yyvsp[(1) - (3)].str) + '\"');
@@ -1776,7 +1832,9 @@ yyreduce:
     break;
 
   case 49:
-#line 269 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 267 "parser.yy"
     {
 		param->set_comment ((yyvsp[(3) - (4)].str));
 		mylog.write ((string) "  comment: " + (yyvsp[(3) - (4)].str));
@@ -1785,7 +1843,9 @@ yyreduce:
     break;
 
   case 50:
-#line 276 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 274 "parser.yy"
     {
 		mylog.write ((string) "including genparse file" + (yyvsp[(2) - (2)].str));
 		free ((yyvsp[(2) - (2)].str));
@@ -1793,7 +1853,9 @@ yyreduce:
     break;
 
   case 51:
-#line 283 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 281 "parser.yy"
     {
 		param->set_short_reps ((yyvsp[(1) - (1)].str));
 		dump_short_reps ((yyvsp[(1) - (1)].str));
@@ -1803,7 +1865,9 @@ yyreduce:
     break;
 
   case 52:
-#line 290 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 288 "parser.yy"
     {
 		param->set_longopt_value (longopt_value.get ());
 		param->set_long_only (true);
@@ -1811,7 +1875,9 @@ yyreduce:
     break;
 
   case 53:
-#line 295 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 293 "parser.yy"
     {
 		param->set_short_reps ((yyvsp[(1) - (3)].str));
 		dump_short_reps ((yyvsp[(1) - (3)].str));
@@ -1820,21 +1886,27 @@ yyreduce:
     break;
 
   case 55:
-#line 304 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 302 "parser.yy"
     {
 		param->set_short_has_arg (optional_argument);
 	}
     break;
 
   case 56:
-#line 308 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 306 "parser.yy"
     {
 		param->set_short_has_arg (no_argument);
 	}
     break;
 
   case 60:
-#line 319 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 317 "parser.yy"
     {
 		param->set_opt_name ((yyvsp[(2) - (2)].str));
 		free ((yyvsp[(2) - (2)].str));
@@ -1842,7 +1914,9 @@ yyreduce:
     break;
 
   case 61:
-#line 324 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 322 "parser.yy"
     {
 		param->set_opt_name ((yyvsp[(2) - (2)].str));
 		free ((yyvsp[(2) - (2)].str));
@@ -1850,33 +1924,43 @@ yyreduce:
     break;
 
   case 62:
-#line 331 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 329 "parser.yy"
     {
 		param->set_opt_name_in_square_braces (true);
 	}
     break;
 
   case 63:
-#line 336 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 334 "parser.yy"
     {}
     break;
 
   case 64:
-#line 338 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 336 "parser.yy"
     {
 		param->set_long_has_arg (optional_argument);
 	}
     break;
 
   case 65:
-#line 342 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 340 "parser.yy"
     {
 		param->set_long_has_arg (no_argument);
 	}
     break;
 
   case 66:
-#line 348 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 346 "parser.yy"
     {
 		param->set_long_rep ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "  long representation: " + (yyvsp[(1) - (1)].str));
@@ -1885,7 +1969,9 @@ yyreduce:
     break;
 
   case 67:
-#line 354 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 352 "parser.yy"
     {
 		param->set_long_rep ((yyvsp[(1) - (1)].str));
 		mylog.write ((string) "  long representation: " + (yyvsp[(1) - (1)].str));
@@ -1894,12 +1980,16 @@ yyreduce:
     break;
 
   case 68:
-#line 361 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 359 "parser.yy"
     { (yyval.p) = int_type; }
     break;
 
   case 69:
-#line 363 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 361 "parser.yy"
     {
 		if (my_params->get_use_gnulib ())
 			(yyval.p) = long_type;
@@ -1910,7 +2000,9 @@ yyreduce:
     break;
 
   case 70:
-#line 371 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 369 "parser.yy"
     {
 		if (my_params->get_use_gnulib ())
 			(yyval.p) = ulong_type;
@@ -1921,7 +2013,9 @@ yyreduce:
     break;
 
   case 71:
-#line 379 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 377 "parser.yy"
     {
 		if (my_params->get_use_gnulib ())
 			(yyval.p) = intmax_type;
@@ -1932,7 +2026,9 @@ yyreduce:
     break;
 
   case 72:
-#line 387 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 385 "parser.yy"
     {
 		if (my_params->get_use_gnulib ())
 			(yyval.p) = uintmax_type;
@@ -1943,12 +2039,16 @@ yyreduce:
     break;
 
   case 73:
-#line 394 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 392 "parser.yy"
     { (yyval.p) = float_type; }
     break;
 
   case 74:
-#line 396 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 394 "parser.yy"
     {
 		if (my_params->get_use_gnulib ())
 			(yyval.p) = double_type;
@@ -1959,27 +2059,37 @@ yyreduce:
     break;
 
   case 75:
-#line 403 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 401 "parser.yy"
     { (yyval.p) = string_type; }
     break;
 
   case 76:
-#line 404 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 402 "parser.yy"
     { (yyval.p) = char_type; }
     break;
 
   case 77:
-#line 405 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 403 "parser.yy"
     { (yyval.p) = flag_type; }
     break;
 
   case 80:
-#line 410 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 408 "parser.yy"
     { (yyval.str) = (yyvsp[(2) - (3)].str); }
     break;
 
   case 82:
-#line 417 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 415 "parser.yy"
     {
 		param->set_low_range ((yyvsp[(1) - (3)].str));
 		mylog.write ((string)"  parameter range: " + (yyvsp[(1) - (3)].str) + "..");
@@ -1988,7 +2098,9 @@ yyreduce:
     break;
 
   case 84:
-#line 427 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 425 "parser.yy"
     {
 		param->set_high_range ((yyvsp[(1) - (1)].str));
 		mylog.write ((string)"  parameter range: .." + (yyvsp[(1) - (1)].str));
@@ -1997,7 +2109,9 @@ yyreduce:
     break;
 
   case 85:
-#line 433 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 431 "parser.yy"
     {
 		param->set_high_range ((yyvsp[(1) - (1)].str));
 		mylog.write ((string)"  parameter range: .." + (yyvsp[(1) - (1)].str));
@@ -2006,12 +2120,16 @@ yyreduce:
     break;
 
   case 89:
-#line 445 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 443 "parser.yy"
     { (yyval.str) = (yyvsp[(1) - (2)].str); }
     break;
 
   case 90:
-#line 449 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 447 "parser.yy"
     {
 		param->add_description ((yyvsp[(1) - (1)].str), false);
 		mylog.write ((string) "  description: " + (yyvsp[(1) - (1)].str));
@@ -2020,7 +2138,9 @@ yyreduce:
     break;
 
   case 91:
-#line 455 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 453 "parser.yy"
     {
 		param->add_description ((yyvsp[(1) - (1)].str), true);
 		mylog.write ((string) "  description starting in 1st column: " + (yyvsp[(1) - (1)].str));
@@ -2029,7 +2149,9 @@ yyreduce:
     break;
 
   case 95:
-#line 468 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 466 "parser.yy"
     {
 		my_params->append_usage_line ((yyvsp[(1) - (1)].str));
 		mylog.write ((string)"  usage string:" + (yyvsp[(1) - (1)].str));
@@ -2038,7 +2160,9 @@ yyreduce:
     break;
 
   case 98:
-#line 480 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 478 "parser.yy"
     {
 		param->add_code_line ((yyvsp[(1) - (2)].str));
 		mylog.write ((string)"  code string:" + (yyvsp[(1) - (2)].str));
@@ -2047,7 +2171,9 @@ yyreduce:
     break;
 
   case 99:
-#line 486 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 484 "parser.yy"
     {
 		param->add_code_line ("");
 		mylog.write ((string)"  code string:");
@@ -2055,27 +2181,35 @@ yyreduce:
     break;
 
   case 100:
-#line 493 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 491 "parser.yy"
     {
 	}
     break;
 
   case 101:
-#line 496 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 494 "parser.yy"
     {
 		(yyval.str) = strdup ((string ("(")).c_str ());
 	}
     break;
 
   case 102:
-#line 500 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 498 "parser.yy"
     {
 		(yyval.str) = strdup ((string (")")).c_str ());
 	}
     break;
 
   case 103:
-#line 504 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 502 "parser.yy"
     {
 		(yyval.str) = strdup ((string ((yyvsp[(1) - (2)].str)) + (yyvsp[(2) - (2)].str)).c_str ());
 		free ((yyvsp[(1) - (2)].str));
@@ -2084,8 +2218,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2091 "parser.cc"
+
+/* Line 1455 of yacc.c  */
+#line 2224 "parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2096,7 +2231,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2161,7 +2295,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2178,7 +2312,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2235,9 +2369,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2262,7 +2393,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2273,7 +2404,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2299,7 +2430,9 @@ yyreturn:
 }
 
 
-#line 510 "parser.yy"
+
+/* Line 1675 of yacc.c  */
+#line 508 "parser.yy"
 
 
 int yyerror (char *s)
